#include "mutex.h"

QMutex treelock(true);

